
//:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
/** @author  John Miller
 *  @version 1.6
 *  @date    Wed Oct  9 18:21:13 EDT 2019
 *  @see     LICENSE (MIT style license file).
 */

package scalation.analytics
package forecaster

import scala.collection.mutable.Set

import scalation.linalgebra.MatriD

//:::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::::
/** The `NoFeatureSelection` trait is for modeling techniques that do not support
 *  feature selection (adding/remove variables from the model).  For example,
 *  `AR_1` only has one feature/predictor variable, so feature selection makes
 *  no sense for this modeling technique.  Therefore the 'forwardSel'
 *  defined in `ForecasterVec` is set to throw an exception.
 */
trait NoFeatureSelectionF
{
    def forwardSel (cols: Set [Int], index_q: Int): (Int, ForecasterVec) =
    {
        throw new UnsupportedOperationException ("forwardSel: this model does not support feature selection")
    } // forwardSel

} // NoFeatureSelectionF trait

